==> jc-1.4.0.tar.gz: javax/swing/JList__243.h <==
// final class javax.swing.JList$3

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 160e17470c19298a javax_swing_AbstractListModel
// @dep_class 4c255184a7b7ffde javax_swing_JList__243

// header file dependencies
// @dep_header javax_swing_AbstractListModel

#include "javax/swing/AbstractListModel.h"

#ifndef _JC_javax_swing_JList__243_H_
#define _JC_javax_swing_JList__243_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Vector$object;
struct _jc_javax_swing_JList$object;

// Typedefs
typedef struct _jc_javax_swing_JList__243$sub_refs	_jc_javax_swing_JList__243$sub_refs;
typedef struct _jc_javax_swing_JList__243$sub_nonrefs	_jc_javax_swing_JList__243$sub_nonrefs;
typedef struct _jc_javax_swing_JList__243$refs	_jc_javax_swing_JList__243$refs;
typedef struct _jc_javax_swing_JList__243$nonrefs	_jc_javax_swing_JList__243$nonrefs;
typedef struct _jc_javax_swing_JList__243$object	_jc_javax_swing_JList__243$object;

typedef const struct _jc_javax_swing_JList__243$vmethods	_jc_javax_swing_JList__243$vmethods;
typedef const struct _jc_javax_swing_JList__243$vtable	_jc_javax_swing_JList__243$vtable;
typedef const struct _jc_javax_swing_JList__243$vtype	_jc_javax_swing_JList__243$vtype;

// Constructors
extern void _jc_javax_swing_JList__243$method$_init$e52f9ae878fc93da(_jc_env *, struct _jc_javax_swing_JList__243$object *, struct _jc_javax_swing_JList$object *, struct _jc_java_util_Vector$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_javax_swing_JList__243$method$getElementAt$be8cb7de3c95b82f(_jc_env *, struct _jc_javax_swing_JList__243$object *, jint);
extern jint _jc_javax_swing_JList__243$method$getSize$82f1d9ee1217ad91(_jc_env *, struct _jc_javax_swing_JList__243$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JList__243$method_info$getElementAt$be8cb7de3c95b82f;
extern _jc_method _jc_javax_swing_JList__243$method_info$getSize$82f1d9ee1217ad91;

// Virtual methods structure
struct _jc_javax_swing_JList__243$vmethods {
	struct _jc_java_lang_Object$object	*(*getElementAt$be8cb7de3c95b82f)(_jc_env *, struct _jc_javax_swing_JList__243$object *, jint);
	jint	(*getSize$82f1d9ee1217ad91)(_jc_env *, struct _jc_javax_swing_JList__243$object *);
};

// Vtable
struct _jc_javax_swing_JList__243$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractListModel$vmethods	javax_swing_AbstractListModel;
	_jc_javax_swing_JList__243$vmethods	javax_swing_JList__243;
};

// Vtype
struct _jc_javax_swing_JList__243$vtype {
	_jc_type			type;
	_jc_javax_swing_JList__243$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JList__243$sub_refs {
	struct _jc_javax_swing_JList$object	*this;
	struct _jc_java_util_Vector$object	*val__24listData;
};

// Reference instance fields (object)
struct _jc_javax_swing_JList__243$refs {
    _jc_javax_swing_JList__243$sub_refs	javax_swing_JList__243;
    _jc_javax_swing_AbstractListModel$sub_refs	javax_swing_AbstractListModel;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JList__243$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JList__243$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractListModel$sub_nonrefs	javax_swing_AbstractListModel;
    _jc_javax_swing_JList__243$sub_nonrefs	javax_swing_JList__243;
};

// Object instance structure
struct _jc_javax_swing_JList__243$object {
	_jc_javax_swing_JList__243$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JList__243$vtype	*vtype;
	_jc_javax_swing_JList__243$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JList__243$vtype _jc_javax_swing_JList__243$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JList__243, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JList__243$class_object;

#endif	/* _JC_javax_swing_JList__243_H_ */

==> jc-1.4.5.tar.gz: javax/swing/JList__243.h <==
// final class javax.swing.JList$3

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 160e17470c19298a javax_swing_AbstractListModel
// @dep_class 4c255184a7b7ffde javax_swing_JList__243

// header file dependencies
// @dep_header javax_swing_AbstractListModel

#include "javax/swing/AbstractListModel.h"

#ifndef _JC_javax_swing_JList__243_H_
#define _JC_javax_swing_JList__243_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Vector$object;
struct _jc_javax_swing_JList$object;

// Typedefs
typedef struct _jc_javax_swing_JList__243$sub_refs	_jc_javax_swing_JList__243$sub_refs;
typedef struct _jc_javax_swing_JList__243$sub_nonrefs	_jc_javax_swing_JList__243$sub_nonrefs;
typedef struct _jc_javax_swing_JList__243$refs	_jc_javax_swing_JList__243$refs;
typedef struct _jc_javax_swing_JList__243$nonrefs	_jc_javax_swing_JList__243$nonrefs;
typedef struct _jc_javax_swing_JList__243$object	_jc_javax_swing_JList__243$object;

typedef const struct _jc_javax_swing_JList__243$vmethods	_jc_javax_swing_JList__243$vmethods;
typedef const struct _jc_javax_swing_JList__243$vtable	_jc_javax_swing_JList__243$vtable;
typedef const struct _jc_javax_swing_JList__243$vtype	_jc_javax_swing_JList__243$vtype;

// Constructors
extern void _jc_javax_swing_JList__243$method$_init$e52f9ae878fc93da(_jc_env *, struct _jc_javax_swing_JList__243$object *, struct _jc_javax_swing_JList$object *, struct _jc_java_util_Vector$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_javax_swing_JList__243$method$getElementAt$be8cb7de3c95b82f(_jc_env *, struct _jc_javax_swing_JList__243$object *, jint) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_JList__243$method$getSize$82f1d9ee1217ad91(_jc_env *, struct _jc_javax_swing_JList__243$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JList__243$method_info$getElementAt$be8cb7de3c95b82f;
extern _jc_method _jc_javax_swing_JList__243$method_info$getSize$82f1d9ee1217ad91;

// Virtual methods structure
struct _jc_javax_swing_JList__243$vmethods {
	struct _jc_java_lang_Object$object	*(*getElementAt$be8cb7de3c95b82f)(_jc_env *, struct _jc_javax_swing_JList__243$object *, jint) _JC_JCNI_ATTR;
	jint	(*getSize$82f1d9ee1217ad91)(_jc_env *, struct _jc_javax_swing_JList__243$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_JList__243$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractListModel$vmethods	javax_swing_AbstractListModel;
	_jc_javax_swing_JList__243$vmethods	javax_swing_JList__243;
};

// Vtype
struct _jc_javax_swing_JList__243$vtype {
	_jc_type			type;
	_jc_javax_swing_JList__243$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JList__243$sub_refs {
	struct _jc_javax_swing_JList$object	*this;
	struct _jc_java_util_Vector$object	*val__24listData;
};

// Reference instance fields (object)
struct _jc_javax_swing_JList__243$refs {
    _jc_javax_swing_JList__243$sub_refs	javax_swing_JList__243;
    _jc_javax_swing_AbstractListModel$sub_refs	javax_swing_AbstractListModel;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JList__243$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JList__243$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractListModel$sub_nonrefs	javax_swing_AbstractListModel;
    _jc_javax_swing_JList__243$sub_nonrefs	javax_swing_JList__243;
};

// Object instance structure
struct _jc_javax_swing_JList__243$object {
	_jc_javax_swing_JList__243$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JList__243$vtype	*vtype;
	_jc_javax_swing_JList__243$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JList__243$vtype _jc_javax_swing_JList__243$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JList__243, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JList__243$class_object;

#endif	/* _JC_javax_swing_JList__243_H_ */
